@@ -1175,7 +1175,7 @@ check_magic_link (HTMLEngine *e, const gchar *text, guint len)
 	    && gtk_html_get_magic_links (e->widget)
 	    && len == 1
 	    && (*text == ' ' || text [0] == '\n' || text [0] == '>' || text [0] == ')'))
-		html_text_magic_link (HTML_TEXT (e->cursor->object), e, html_object_get_length (e->cursor->object));
+		html_text_magic_link (HTML_TEXT (e->cursor->object), e, 1);
 }
 
 static void
@@ -1490,7 +1490,7 @@ html_engine_paste_link (HTMLEngine *e, const gchar *text, gint len, const gchar
 	}
 
 	html_engine_paste_text (e, text, len);
-	html_text_add_link (HTML_TEXT (e->cursor->object), e, url, target, e->cursor->offset >= len ? e->cursor->offset - len : 0, e->cursor->offset);
+	html_text_add_link (HTML_TEXT (e->cursor->object), e, url, target, e->cursor->offset - len, e->cursor->offset);
 
 	g_free (url);
 }
